function a2_gs_relax ( omega, x0 )
% A2_GS_RELAX - Gau-Seidel-Relaxations-Verfahren
%
% Synopsis:
%    a2_gs_relax ( omega, x0 )
%
% Return values:
%    (none)
%
% 2001-02-06, Stephan Engelke, Andreas Meister

A       = [ 4 0  2;
	    0 5  2;
	    5 4 10 ];

eps     = 1e-12;			% stopping tolerance
maxiter = 10000;			% maximum number of iterations

% no user servicable parts below
n       = size (A, 1);			% matrix size, number of rows
rhs     = [ 4; -3 ; 2];

k       = 0;				% iteration counter

% iteration 0
x       = x0;
xnew    = zeros (n,1);			% initialize (for correct size)

for i=1:n
  xnew(i) =  (1-omega) * x(i) + omega/A(i,i) ...
      * ( rhs(i) - sum(A(i,1:i-1) .* xnew(1:i-1)')  ...
	  - sum(A(i,i+1:n) .* x(i+1:n)') );
end

xnorm   = norm ( xnew - x, inf) ;

while ( (xnorm > eps) & (k < maxiter) )
  fprintf ('%3i\t%e\n', k,  xnorm );
  x = xnew;
  
  for i=1:n
    xnew(i) =  (1-omega) * x(i) + omega/A(i,i) ...
	* ( rhs(i) - sum(A(i,1:i-1) .* xnew(1:i-1)')  ...
	    - sum(A(i,i+1:n) .* x(i+1:n)') );
  end

  xnorm = norm ( xnew - x, inf);
  k = k + 1;
end

fprintf ('%3i\t%e\n', k,  xnorm );

%%% EOF %%%